==> owlsight-2.0.1b1.tar.gz: owlsight-2.0.1b1/tests/conftest.py <==
import pytest
from typing import List, Optional, Dict, Any, Union

from owlsight.processors.base import TextGenerationProcessor
from owlsight.processors.text_generation_manager import TextGenerationManager
from owlsight.configurations.config_manager import ConfigManager


class MockTextGenerationProcessor(TextGenerationProcessor):
    def __init__(
        self,
        model_id: str,
        save_history: bool = False,
        mock_responses: Union[str, List[str]] = "Default mock response",
    ):
        super().__init__(model_id, save_history, system_prompt=None)
        self.mock_responses = [mock_responses] if isinstance(mock_responses, str) else mock_responses
        self.response_index = 0

    def generate(
        self,
        input_data: str,
        max_new_tokens: int = 512,
        temperature: float = 0.0,
        stopwords: Optional[List[str]] = None,
        generation_kwargs: Optional[Dict[str, Any]] = None,
    ) -> str:
        response = self.mock_responses[self.response_index % len(self.mock_responses)]
        self.response_index += 1

        if self.save_history:
            self.history.append((input_data, response))
        return response


@pytest.fixture
def mock_text_generator(request):
    mock_responses = getattr(request, "param", "Default mock response")
    if isinstance(mock_responses, list) and len(mock_responses) == 1:
        mock_responses = mock_responses[0]
    return MockTextGenerationProcessor("mock-model", save_history=True, mock_responses=mock_responses)


@pytest.fixture
def config_manager():
    return ConfigManager()


@pytest.fixture
def text_generation_manager(config_manager):
    return TextGenerationManager(config_manager=config_manager)

@pytest.fixture
def media_model_mappings():
    return {
        "image-to-text": "Salesforce/blip-image-captioning-base",
        "visual-question-answering": "dandelin/vilt-b32-finetuned-vqa",
        "automatic-speech-recognition": "facebook/wav2vec2-base-960h",
        "document-question-answering": "microsoft/layoutlm-base-uncased",
    }

==> owlsight-2.1.0.tar.gz: owlsight-2.1.0/tests/conftest.py <==
import pytest
from typing import List, Optional, Dict, Any, Union

from owlsight.processors.base import TextGenerationProcessor
from owlsight.processors.text_generation_manager import TextGenerationManager
from owlsight.configurations.config_manager import ConfigManager


class MockTextGenerationProcessor(TextGenerationProcessor):
    def __init__(
        self,
        model_id: str,
        apply_chat_history: bool = False,
        mock_responses: Union[str, List[str]] = "Default mock response",
    ):
        super().__init__(model_id, apply_chat_history, system_prompt=None)
        self.mock_responses = [mock_responses] if isinstance(mock_responses, str) else mock_responses
        self.response_index = 0

    def generate(
        self,
        input_data: str,
        max_new_tokens: int = 512,
        temperature: float = 0.0,
        stopwords: Optional[List[str]] = None,
        generation_kwargs: Optional[Dict[str, Any]] = None,
    ) -> str:
        response = self.mock_responses[self.response_index % len(self.mock_responses)]
        self.response_index += 1

        if self.apply_chat_history:
            self.chat_history.append((input_data, response))
        return response


@pytest.fixture
def mock_text_generator(request):
    mock_responses = getattr(request, "param", "Default mock response")
    if isinstance(mock_responses, list) and len(mock_responses) == 1:
        mock_responses = mock_responses[0]
    return MockTextGenerationProcessor("mock-model", apply_chat_history=True, mock_responses=mock_responses)


@pytest.fixture
def config_manager():
    return ConfigManager()


@pytest.fixture
def text_generation_manager(config_manager):
    return TextGenerationManager(config_manager=config_manager)

@pytest.fixture
def media_model_mappings():
    return {
        "image-to-text": "Salesforce/blip-image-captioning-base",
        "visual-question-answering": "dandelin/vilt-b32-finetuned-vqa",
        "automatic-speech-recognition": "facebook/wav2vec2-base-960h",
        "document-question-answering": "microsoft/layoutlm-base-uncased",
    }
